#include <BLEPeripheral.h>

// LED Pin Definitions
const int ledPin1 = 9; // Change this to the appropriate GPIO pin number for your setup

// BLE Service and Characteristic UUIDs
#define LED_SERVICE_UUID "19B10000-E8F2-537E-4F6C-D104768A1214"
#define LED_CHARACTERISTIC_UUID "6F3FEC1D-118D-4D0E-BD5B-1D16E7A8AC0F"

// Create a BLEPeripheral object
BLEPeripheral blePeripheral;

// Create a BLEService for LED control
BLEService ledService(LED_SERVICE_UUID);

// Create a BLECharacteristic for LED control
BLECharacteristic ledCharacteristic(LED_CHARACTERISTIC_UUID, BLEWrite, 20); // Allow for a string up to 20 characters

void setup() {
  // Initialize the LED pin as an output
  pinMode(ledPin1, OUTPUT);
  digitalWrite(ledPin1, LOW); // Turn LED OFF initially

  // Set the local name and advertise the BLE service
  blePeripheral.setLocalName("LED_Control");
  blePeripheral.setAdvertisedServiceUuid(ledService.uuid());

  // Add the characteristic to the service
  blePeripheral.addAttribute(ledCharacteristic);

  // Add the service to the BLE peripheral
  blePeripheral.addAttribute(ledService);

  // Start advertising the BLE service
  blePeripheral.begin();

  // Print a message indicating that the BLE service is ready
  Serial.println("BLE LED Control Service is now available. Connect to control the LED.");
}

void loop() {
  // Listen for BLE connections
  BLECentral central = blePeripheral.central();

  // If a central is connected...
  if (central) {
    // Print the central's address
    Serial.print("Connected to central: ");
    Serial.println(central.address());

    // While the central is still connected...
    while (central.connected()) {
      // Check if the central has written to the LED characteristic
      if (ledCharacteristic.written()) {
        Serial.print("charWritten");
        // Read the value written by the central as a string
        String value = String((char*)ledCharacteristic.value());

        // Process the received command (here, we'll just print it)
        Serial.print("Received value: ");
        Serial.println(value);
      }
    }

    // When the central disconnects, print a message
    Serial.print("Disconnected from central: ");
    Serial.println(central.address());
  }
}
